package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.document.ExplainDocument;

import java.util.List;

/**
 * 说明文档Mapper接口
 * 
 * @author boman
 * @date 2024-04-29
 */
public interface ExplainDocumentMapper 
{
    /**
     * 查询说明文档
     * 
     * @param explainId 说明文档主键
     * @return 说明文档
     */
    public ExplainDocument selectExplainDocumentByExplainId(Integer explainId);

    /**
     * 查询说明文档列表
     * 
     * @param explainDocument 说明文档
     * @return 说明文档集合
     */
    public List<ExplainDocument> selectExplainDocumentList(ExplainDocument explainDocument);

    /**
     * 新增说明文档
     * 
     * @param explainDocument 说明文档
     * @return 结果
     */
    public int insertExplainDocument(ExplainDocument explainDocument);

    /**
     * 修改说明文档
     * 
     * @param explainDocument 说明文档
     * @return 结果
     */
    public int updateExplainDocument(ExplainDocument explainDocument);

    /**
     * 删除说明文档
     * 
     * @param explainId 说明文档主键
     * @return 结果
     */
    public int deleteExplainDocumentByExplainId(Integer explainId);

    /**
     * 批量删除说明文档
     * 
     * @param explainIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteExplainDocumentByExplainIds(Integer[] explainIds);
}
